@@ -382,9 +382,11 @@ def dependence(
 
     * `xi`: [np.array]:
         The points at which the partial dependence was evaluated.
-
     * `yi`: [np.array]:
         The value of the model at each point `xi`.
+    * `stddevs`: [np.array]:
+        The standard deviation of the model at each point `xi`.
+
 
     For 2D partial dependence:
 
@@ -421,6 +423,7 @@ def dependence(
         # categorical values
         xi, xi_transformed = _evenly_sample(space.dimensions[i], n_points)
         yi = []
+        stddevs = []
         for x_ in xi_transformed:
             rvs_ = np.array(sample_points)  # copy
             # We replace the values in the dimension that we want to keep fixed
@@ -428,9 +431,14 @@ def dependence(
             # In case of `x_eval=None` rvs conists of random samples.
             # Calculating the mean of these samples is how partial dependence
             # is implemented.
-            yi.append(np.mean(model.predict(rvs_)))
-
-        return xi, yi
+            funcvalue, stddev = model.predict(rvs_, return_std = True)
+            yi.append(np.mean(funcvalue))
+            stddevs.append(np.mean(stddev))
+        # Convert yi and stddevs from lists to numpy arrays
+        yi = np.array(yi)
+        stddevs = np.array(stddevs)
+        
+        return xi, yi, stddevs
 
     else:
         xi, xi_transformed = _evenly_sample(space.dimensions[j], n_points)
@@ -461,6 +469,7 @@ def plot_objective(
     pars="result",
     expected_minimum_samples=None,
     title=None,
+    show_confidence=False,
 ):
     """Pairwise dependence plot of the objective function.
 
@@ -502,7 +511,8 @@ def plot_objective(
     * `dimensions` [list of str, default=None] Labels of the dimension
         variables. `None` defaults to `space.dimensions[i].name`, or
         if also `None` to `['X_0', 'X_1', ..]`.
-    * `usepartialdependence` [bool, default=false] Wether to use partial
+
+    * `usepartialdependence` [bool, default=false] Whether to use partial
         dependence or not when calculating dependence. If false plot_objective
         will parse values to the dependence function,
         defined by the pars argument
@@ -519,6 +529,7 @@ def plot_objective(
                 currently does not work with categorical values.
             'expected_minimum_random' - Parameters that gives the best minimum
                 when using naive random sampling. Works with categorical values
+            '[x[0], x[1], ..., x[n]] - Parameter to show depence from a given x
 
     * `expected_minimum_samples` [float, default = None] Determines how many
     points should be evaluated to find the minimum when using
@@ -527,6 +538,9 @@ def plot_objective(
     * `title` [str, default=None]
         String to use as title of the figure
 
+    * `show_confidence` [bool, default=false] Whether or not to show a credible
+        range around the mean estimate on the 1d-plots in the diagonal. The
+        credible range is given as 1.96 times the std in the point.
 
     Returns
     -------
@@ -543,12 +557,7 @@ def plot_objective(
             # Using the best observed result
             x_vals = result.x
         elif pars == "expected_minimum":
-            if result.space.is_partly_categorical:
-                # space is also categorical
-                raise ValueError(
-                    text="expected_minimum does not support any \
-                categorical values"
-                )
+
             # Do a gradient based minimum search using scipys own minimizer
             if expected_minimum_samples:
                 # If a value for expected_minimum_samples has been parsed
@@ -638,8 +647,9 @@ def plot_objective(
                 # to avoid duplicates.
                 break
 
+            # The diagonal of the plot
             elif i == j:
-                xi, yi = dependence(
+                xi, yi, stddevs = dependence(
                     space,
                     result.models[-1],
                     i,
@@ -648,12 +658,21 @@ def plot_objective(
                     n_points=n_points,
                     x_eval=x_eval,
                 )
-                row.append({"xi": xi, "yi": yi})
+                row.append({"xi": xi, "yi": yi, "std": stddevs})
+
+                
+                if show_confidence:
+                    yi_low_bound = yi - 1.96 * stddevs
+                    yi_high_bound = yi + 1.96 * stddevs
+                else:
+                    yi_low_bound = yi
+                    yi_high_bound = yi
+                if np.min(yi_low_bound) < val_min_1d:
+                    val_min_1d = np.min(yi_low_bound)
+                if np.max(yi_high_bound) > val_max_1d:
+                    val_max_1d = np.max(yi_high_bound)
+
 
-                if np.min(yi) < val_min_1d:
-                    val_min_1d = np.min(yi)
-                if np.max(yi) > val_max_1d:
-                    val_max_1d = np.max(yi)
 
             # lower triangle
             else:
@@ -684,14 +703,24 @@ def plot_objective(
                 # to avoid duplicates.
                 break
 
+            # The diagonal of the plot, showing the 1D (partial) dependence for each of the n parameters
             elif i == j:
 
                 xi = plots_data[i][j]["xi"]
                 yi = plots_data[i][j]["yi"]
+                stddevs = plots_data[i][j]["std"]
 
                 ax[i, i].plot(xi, yi)
-                ax[i, i].set_ylim(val_min_1d, val_max_1d)
+                ax[i, i].set_xlim(np.min(xi), np.max(xi))
+                ax[i, i].set_ylim(val_min_1d-abs(val_min_1d)*.02, val_max_1d+abs(val_max_1d)*.02)
                 ax[i, i].axvline(minimum[i], linestyle="--", color="r", lw=1)
+                if show_confidence:
+                    ax[i, i].fill_between(xi, 
+                                          y1=(yi - 1.96*stddevs),
+                                          y2=(yi + 1.96*stddevs),
+                                          alpha=0.5,
+                                          color='red',
+                                          linewidth=0.0)
 
             # lower triangle
             elif i > j:
@@ -711,9 +740,9 @@ def plot_objective(
                     vmax=val_max_2d,
                 )
                 ax[i, j].scatter(
-                    samples[:, j], samples[:, i], c="darkorange", s=10, lw=0.0
+                    samples[:, j], samples[:, i], c="darkorange", s=10, lw=0.0, zorder=10, clip_on=False
                 )
-                ax[i, j].scatter(minimum[j], minimum[i], c=["r"], s=20, lw=0.0)
+                ax[i, j].scatter(minimum[j], minimum[i], c=["r"], s=20, lw=0.0, zorder=10, clip_on=False)
 
                 if [i, j] == [1, 0]:
                     import matplotlib as mpl
@@ -731,12 +760,26 @@ def plot_objective(
         ylabel = "Partial dependence"
     else:
         ylabel = "Dependence"
+
     return _format_scatter_plot_axes(
         ax, space, ylabel=ylabel, dim_labels=dimensions
     )
 
 
-def plot_objectives(results, titles=None):
+def plot_objectives(
+    results,
+    levels=10,
+    n_points=40,
+    n_samples=250,
+    size=2,
+    zscale="linear",
+    dimensions=None,
+    usepartialdependence=True,
+    pars="result",
+    expected_minimum_samples=None,
+    titles=None,
+    show_confidence=False
+    ):
     """Pairwise dependence plots of each of the objective functions.
     Parameters
     ----------
@@ -751,11 +794,33 @@ def plot_objectives(results, titles=None):
 
     if titles is None:
         for result in results:
-            plot_objective(result, title=None)
+            plot_objective(result,
+                           levels=levels,
+                           n_points=n_points,
+                           n_samples=n_samples,
+                           size=size,
+                           zscale=zscale,
+                           dimensions=dimensions,
+                           usepartialdependence=usepartialdependence,
+                           pars=pars,
+                           expected_minimum_samples=expected_minimum_samples,
+                           title=None,
+                           show_confidence=show_confidence)
         return
     else:
         for k in range(len(results)):
-            plot_objective(results[k], title=titles[k])
+            plot_objective(results[k], 
+                           levels=levels,
+                           n_points=n_points,
+                           n_samples=n_samples,
+                           size=size,
+                           zscale=zscale,
+                           dimensions=dimensions,
+                           usepartialdependence=usepartialdependence,
+                           pars=pars,
+                           expected_minimum_samples=expected_minimum_samples,
+                           title=titles[k],
+                           show_confidence=show_confidence)
         return
 
 
@@ -832,8 +897,10 @@ def plot_evaluations(result, bins=20, dimensions=None):
                     s=40,
                     lw=0.0,
                     cmap="viridis",
+                    zorder=10,
+                    clip_on=False
                 )
-                ax[i, j].scatter(minimum[j], minimum[i], c=["r"], s=20, lw=0.0)
+                ax[i, j].scatter(minimum[j], minimum[i], c=["r"], s=20, lw=0.0, zorder=10, clip_on=False)
 
     return _format_scatter_plot_axes(
         ax, space, ylabel="Number of samples", dim_labels=dimensions
@@ -923,9 +990,24 @@ def plot_expected_minimum_convergence(
     of the surogate model in the expected minimum together with a measure for
     the variability in the suggested mean value. This code "replays" the
     entire optimization, hence it builds quiet many models and can, thus, seem
-    slow. TODO: Consider allowing user to subselect in data, to e.g. perform
+    slow. 
+    TODO: Consider allowing user to subselect in data, to e.g. perform
     the analysis using every n-th datapoint, or only performing the analysis
     for the last n datapoints.
+
+    Args:
+        result ([`OptimizeResult`]): The result returned from a opt.tell
+        command or from using get_result() or create_result()
+        figsize (`tuple`, optional): [Gives the desired size of the resulting
+        chart]. Defaults to (15, 15).
+        random_state ([`Int`], optional): [abbility to pass random state to
+        ensure reproducibility in plotting]. Defaults to None.
+        sigma (`float`, optional): [Sigma gives a slight gaussian smoothing to
+        the depiction of the credible interval around the expected minimum
+        value.]. Defaults to 0.5.
+
+    Returns:
+        [ax]: [description]
     """
 
     estimated_mins_x = []
@@ -1058,7 +1140,7 @@ def plot_Pareto(
         annot.xy = pos
 
         exp_params = vals[ind["ind"][0]]
-        values = ["%.3f" % number for number in exp_params]
+        values = [str(number) for number in exp_params]
         strings = []
         for dim, value in zip(dimensions, values):
             strings.append(dim + ": " + value + str("\n"))
